.. _changelog:

==========
Change Log
==========

v0.1.1 (2019/5/13)
==================

- KLIFF available from PyPI now. Using ``$pip install kliff`` to install.

- Use SW model from the KIM website in tutorial.

- Format code with ``black``.


v0.1.0 (2019/3/29)
==================
First official release, but API is not guaranteed to be stable.

- Add more docs to :ref:`reference`.


v0.0.1 (2019/1/1)
=================
Pre-release.
